# The Menubar itself (this can run as standalone for testing purposes)
import sys
import pygtk
pygtk.require("2.0")
import gtk
import gtk.glade
import Images
import cairo
import pango
import os
import urllib
import gconf
import string
from Cairo_Window import CairoWindow
#Check requirements for the following
import xdg.Menu
import xdg.IconTheme
import xdg.Locale
import optparse
import os.path
from xdg.DesktopEntry import *
#XML support
import xml.dom.minidom

def ConstructMainMenu():
    print "Building main menu template..."
    Images.BaseMenu = xdg.Menu.parse("")  #Get the base menu
    #This builds the main menu template, so that XGD methods do not have
    #to be used every time it is called, this increases the load speed.
    menu = Images.BaseMenu
    Images.elist = []
    Images.ebuttonnamelist = []
    Images.ebuttoniconlist = []
    Images.etypelist = []
    
    for entry in menu.getEntries():
        if isinstance(entry, xdg.Menu.Menu):
            Images.ebuttonnamelist.append(entry.getName())
            Images.ebuttoniconlist.append(entry.getIcon())
            Images.elist.append(entry)
            Images.etypelist.append(1)
        elif isinstance(entry, xdg.Menu.MenuEntry):
            desktop = DesktopEntry(entry.DesktopEntry.getFileName())
            dn = str(desktop.getName())
            if dn != "My Documents":
                Images.ebuttonnamelist.append(desktop.getName())
                Images.ebuttoniconlist.append(desktop.getIcon())
                Images.elist.append(desktop)
                Images.etypelist.append(0)


class Main_Menu():
    def __init__(self): 
        if Images.EnableCompositing==1:
            # Set up the user icon
            self.usericon = CairoWindow()
            self.usericon.Create(self,2)
        
        #Set the Glade file
        self.wTree = gtk.glade.XML(Images.GladeFile)
        self.window = self.wTree.get_widget("MainMenu")
        self.window.set_app_paintable(1)
        self.window.set_skip_taskbar_hint(1)
        self.window.set_skip_pager_hint(1)
        self.window.set_keep_above(0)       #Make this always above other windows
        self.window.stick()                 #Make this appear on all desktops

        #Get the Main Window, and connect the "destroy" event
        if (self.window):
            dic = { "on_TopButton_clicked" : self.Button_Top_Clicked,
	                "on_MainMenu_destroy_event" : gtk.main_quit}
            self.wTree.signal_autoconnect(dic)
            self.window.connect("focus-out-event", self.internal_destroy)
            self.window.connect("key-press-event", self.key_down)
    
    def auxdestroyed(self):
        #dummy sub for module compatibility
        pass
    
    def destroy(self):
        # External Obliterator
        if Images.EnableCompositing == 1:
            self.usericon.destroy()
        self.window.destroy()
        gtk.main_quit()
        
    def internal_destroy(self,widget,event):
        # Internal Obliterator (event driven)
        self.window.destroy()
        if Images.EnableCompositing == 1:
            self.usericon.destroy()
        gtk.main_quit()

#=================================================================
#WINDOW SETUP
#=================================================================


    def setup(self,win_x, win_y):
		#Standard setup of window
		tmp = self.window.get_size()
		win_x = win_x + Images.StartMenuXOffset
		# Change from beta 1, make it go down if in the top part of the screen
		# May want to adjust theme to make it look prettier when doing this tho
		#screen = gtk.gdk.screen_get_default()
		self.screenmidpty = int(Images.screenheight / 2)
		if win_y < self.screenmidpty:
			win_y = win_y - Images.StartMenuYOffset
		else:
			win_y = win_y - tmp[1] + Images.StartMenuYOffset
		self.win_x = win_x
		self.win_y = win_y
		self.window.move(win_x, win_y)
		# Set up the UserPic
		self.ChangeUserPic_Normalise()

		# Set menu background image
		self.background =  self.wTree.get_widget("Background")

		# Set window shape from alpha mask of background image
		self.bgpb = gtk.gdk.pixbuf_new_from_file(Images.StartMenuTemplate)
		self.bgpbim, self.bgpbms = self.bgpb.render_pixmap_and_mask(alpha_threshold=128)
		self.background.set_from_pixmap(self.bgpbim, self.bgpbms)

		#self.window.input_shape_combine_mask(self.bgpbms,0,0)
		self.window.shape_combine_mask(self.bgpbms, 0, 0)

		# Obtain OS default icon theme
		gconf_client = gconf.client_get_default()
		self.DefaultIconTheme = gconf_client.get_string("/desktop/gnome/interface/icon_theme")


		# Set Top Menu Icons from current system theme directory (assume standard gnome icon structure)
		self.Pic = gtk.gdk.pixbuf_new_from_file_at_size(Images.Browser, 36, 36)
		self.Img = gtk.Image()
		self.Img.set_from_pixbuf(self.Pic)
		self.Button =  self.wTree.get_widget("InternetButton")
		#Align button
		self.Button.set_alignment(0, .5)
		#Add client names to button labels
		self.lbl = self.Button.get_label()
		self.lbl = self.lbl + Images.BrowserName
		self.Button.set_label(self.lbl)
		self.Button.set_image(self.Img)
		self.Pic = gtk.gdk.pixbuf_new_from_file_at_size(Images.Email, 36, 36)
		self.Img = gtk.Image()
		self.Img.set_from_pixbuf(self.Pic)
		self.Button =  self.wTree.get_widget("EmailButton")
		self.Button.set_alignment(0, .5)
		self.lbl = self.Button.get_label()
		self.lbl = self.lbl + Images.EmailName
		self.Button.set_label(self.lbl)        
		self.Button.set_image(self.Img)

		#Set event for searchbar
		self.SearchBar =  self.wTree.get_widget("SearchBar")
		self.SearchBar.connect("activate",self.SearchBarActivate)

		#SET CUSTOM BUTTON DEFAULT IMAGES
		self.Setimage(Images.PowerButton, "PowerButtonImage")
		self.Setimage(Images.LockButton, "LockButtonImage")
		self.Setimage(Images.AuxButton, "AuxButtonImage")
		#Power Button
		self.Button =  self.wTree.get_widget("PowerButton")
		self.Button.connect("enter-notify-event", self.PowerButton_enter)
		self.Button.connect("leave-notify-event", self.PowerButton_leave)
		self.Button.connect("button-release-event", self.PowerButton_click)
		#Lock Button
		self.Button =  self.wTree.get_widget("LockButton")
		self.Button.connect("enter-notify-event", self.LockButton_enter)
		self.Button.connect("leave-notify-event", self.LockButton_leave)
		self.Button.connect("button-release-event", self.LockButton_click)
		#Aux Button
		self.Button =  self.wTree.get_widget("AuxButton")
		self.Button.connect("enter-notify-event", self.AuxButton_enter)
		self.Button.connect("leave-notify-event", self.AuxButton_leave)
		self.Button.connect("button-release-event", self.AuxButton_click)

		#Right hand Menu Buttons (in order)
		self.AddCustomButton("M_Home")
		self.AddCustomButton("M_Documents")
		self.AddCustomButton("M_Pictures")
		self.AddCustomButton("M_Music")
		self.AddCustomButton("M_Games")
		self.AddCustomButton("M_Search")
		self.AddCustomButton("M_RecentItems")
		self.AddCustomButton("M_Computer")
		self.AddCustomButton("M_Network")
		self.AddCustomButton("M_Connect")
		self.AddCustomButton("M_ControlPanel")
		self.AddCustomButton("M_Defaults")
		self.AddCustomButton("M_Help")

		# Configure the Program List
		self.ProgramListPopulate()



		self.window.present()
                
    def key_down (self,widget,event):
        # Key down
        key = event.hardware_keycode
        if key == 9:
            #Escape Key, nukes window
            self.internal_destroy(None,None)
            
#=================================================================
#TOP MENU BAR BUTTONS EVENTS
#=================================================================

    def Button_Top_Clicked(self,widget):        
        self.wn = widget.name
        if self.wn == "InternetButton":
            gconf_client = gconf.client_get_default()
            self.client = gconf_client.get_string("/desktop/gnome/applications/browser/exec")
            self.client = self.strip(self.client)
            os.spawnlp(os.P_NOWAIT,self.client)
            self.internal_destroy(None,None)
        elif self.wn == "EmailButton":
            gconf_client = gconf.client_get_default()
            self.client = gconf_client.get_string("/desktop/gnome/url-handlers/mailto/command")
            self.client = self.strip(self.client)
            print self.client
            os.spawnlp(os.P_NOWAIT,self.client)
            self.internal_destroy(None,None)
            
    def strip(self,stringval):
        # Return only the first word in a string
        self.i = stringval.split()
        return self.i[0]

#=================================================================
#POWER BUTTON EVENTS
#=================================================================
    def PowerButton_enter(self,widget,event):
        self.Setimage(Images.PowerButtonSel, "PowerButtonImage")
    def PowerButton_leave(self,widget,event):
        self.Setimage(Images.PowerButton, "PowerButtonImage")
    def PowerButton_click(self,widget,event):
        os.spawnvp(os.P_NOWAIT,"gnome-session-save",["gnome-session-save", "--kill"])
        self.internal_destroy(None,None)
#=================================================================
#LOCK BUTTON EVENTS
#=================================================================
    def LockButton_enter(self,widget,event):
        self.Setimage(Images.LockButtonSel, "LockButtonImage")
    def LockButton_leave(self,widget,event):
        self.Setimage(Images.LockButton, "LockButtonImage")
    def LockButton_click(self,widget,event):
        os.spawnvp(os.P_NOWAIT,"gnome-screensaver-command",["gnome-screensaver-command", "--lock"])
        self.internal_destroy(None,None)
#=================================================================
#AUX BUTTON EVENTS
#=================================================================
    def AuxButton_enter(self,widget,event):
        self.Setimage(Images.AuxButtonSel, "AuxButtonImage")
    def AuxButton_leave(self,widget,event):
        self.Setimage(Images.AuxButton, "AuxButtonImage")
    def AuxButton_click(self,widget,event):
        self.CreateAFMenu()
#=================================================================
#Right Hand Side panel
#=================================================================
    def RPanelBar_enter(self,widget,event):
        # Called when the mouse enters an event box
        if widget.name != Images.M_CurrentIconSet:
            self.Setvisable(Images.M_CurrentIconSet, False)
        Images.M_CurrentIconSet = widget.name
        self.Setvisable(Images.M_CurrentIconSet, True)
        
        if Images.EnableCompositing == 1:
            self.usericon.mode = 1
            #self.usericon.move(self.win_x + 308 ,self.win_y + 5)
            self.UserPicName = self.RMenuImageLookup(Images.M_CurrentIconSet,1)
            self.usericon.updateimage(self.UserPicName)
            self.usericon.update()

    def RPanelBar_leave(self,widget,event):     #Called when the mouse leaves an event box
        self.LeaveCustomState()
        
    def RPanelBar_click(self,widget,event):
        # Called in response to a click in an event box
        print widget.name + " called click event"
        self.closewin = self.RMenuFunctionLookup(widget.name)
        if self.closewin == 0:
            self.internal_destroy(None,None)

    def RMenuFunctionLookup(self,widgetname):
		if widgetname=="M_Home":
			self.k = Images.Actions[0]
		elif widgetname=="M_Documents":
			self.k = Images.Actions[1]
		elif widgetname=="M_Pictures":
			self.k = Images.Actions[2]
		elif widgetname=="M_Music":
			self.k = Images.Actions[3]
		elif widgetname=="M_Games":
			self.k = Images.Actions[4]
		elif widgetname=="M_Search":
			self.k = Images.Actions[5]
		elif widgetname=="M_RecentItems":
			self.CreateRIMenu()
			return 1
		elif widgetname=="M_Computer":
			self.k = Images.Actions[6]
		elif widgetname=="M_Network":
			self.k = Images.Actions[7]
		elif widgetname=="M_Connect":
			self.k = Images.Actions[8]
		elif widgetname=="M_ControlPanel":
			self.k = Images.Actions[9]
		elif widgetname=="M_Defaults":
			self.k = Images.Actions[10]
		elif widgetname=="M_Help":
			self.k = Images.Actions[11]
		self.k = string.replace(self.k, "[home]", Images.HomeDirectory)
		self.kp = self.k.split()
		os.spawnvp(os.P_NOWAIT,self.kp[0],self.kp)
		return 0        
        
    def RMenuImageLookup(self,widgetname, sel):
        if widgetname=="M_Home":return Images.M_Home[sel]
        if widgetname=="M_Documents":return Images.M_Documents[sel]
        if widgetname=="M_Pictures":return Images.M_Pictures[sel]
        if widgetname=="M_Music":return Images.M_Music[sel]
        if widgetname=="M_Games":return Images.M_Games[sel]
        if widgetname=="M_Search":return Images.M_Search[sel]
        if widgetname=="M_RecentItems":return Images.M_RecentItems[sel]
        if widgetname=="M_Computer":return Images.M_Computer[sel]
        if widgetname=="M_Network":return Images.M_Network[sel]
        if widgetname=="M_Connect":return Images.M_Connect[sel]
        if widgetname=="M_ControlPanel":return Images.M_ControlPanel[sel]
        if widgetname=="M_Defaults":return Images.M_Defaults[sel]
        if widgetname=="M_Help":return Images.M_Help[sel]
                
    def AddCustomButton(self,widgetname):
        self.Button =  self.wTree.get_widget(widgetname)
        self.Button.connect("enter-notify-event", self.RPanelBar_enter)
        self.Button.connect("leave-notify-event", self.RPanelBar_leave)
        self.Button.connect("button-release-event", self.RPanelBar_click)
        self.Setimage(self.RMenuImageLookup(widgetname,0), widgetname + "Image")
        self.Setvisable(widgetname,False)

#=================================================================
#GLADE METHODS
#=================================================================
    #Set an image from a png file
    def Setimage(self,imagefile,gladename):
        self.Pic = gtk.gdk.pixbuf_new_from_file(imagefile)
        self.ImageObject =  self.wTree.get_widget(gladename)
        self.ImageObject.set_from_pixbuf(self.Pic)

    #Set visibility of an event box object
    def Setvisable(self,gladename, visibility):
        self.ImageObject =  self.wTree.get_widget(gladename)
        if self.ImageObject:
            self.ImageObject.set_visible_window(visibility)

    def LeaveCustomState(self):
        self.Setvisable(Images.M_CurrentIconSet, False)
        if Images.EnableCompositing == 1:
            self.ChangeUserPic_Normalise()

    def ChangeUserPic_Normalise(self):
        # Restore userpic to mode 2  (speed lag if overwriting already current values)
        # Place the usericon        
        if Images.EnableCompositing == 1:
            self.usericon.mode = 2
            self.usericon.move(self.win_x + Images.UserIconFrameOffsetX,self.win_y  + Images.UserIconFrameOffsetY)
            self.usericon.update()
            self.usericon.updateimage(Images.UserImageFrame)
            self.usericon.updatesecondimage(Images.UserImage)
        
#=================================================================
#PROGRAM LIST
#=================================================================
    def ProgramListPopulate(self):
        #Build the gtk widget succession
        self.ConstructGTKObjectsMenu()
        #Initialise and populate menu
        self.name="Applications"
        self.BaseMenu = Images.BaseMenu
        self.CurMenu = self.BaseMenu
        #Previous menus are stored in a list, going 'back' just pulls the last one off the end of the list
        self.PrevMenus = []
        self.XGDMenu(self.BaseMenu,0)

    def ConstructGTKObjectsMenu(self):
        # Create components Frame -> ScrollFrame -> EventBox -> VBox -> Buttons
        self.Frame = self.wTree.get_widget("MenuFrame")
        self.ScrollFrame = gtk.ScrolledWindow()
        self.PLVBox = gtk.VBox(False)
        self.SFEB = gtk.EventBox()
        self.SFEB.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("white"))
        #self.SFEB.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("black"))
        #Configure the scrollframe
        self.ScrollFrame.set_size_request(Images.PG_buttonframedimensions[0],Images.PG_buttonframedimensions[1])      
        self.ScrollFrame.set_shadow_type(gtk.SHADOW_NONE)
        self.ScrollFrame.set_policy(gtk.POLICY_NEVER,gtk.POLICY_AUTOMATIC)
        #Build structure
        self.ScrollFrame.add_with_viewport(self.SFEB)
        self.SFEB.add(self.PLVBox)
        self.Frame.put(self.ScrollFrame,Images.PG_buttonframe[0],Images.PG_buttonframe[1])
        #Show newly created widgets
        self.SFEB.show()
        self.PLVBox.show()
        self.ScrollFrame.show()


    def AddButton(self,name,icon,bold):
        self.Button = gtk.Button(name)
        #40 for Fav Apps button
        iconfile=self.geticonfile(icon)
        if bold:
            pass
            #FIXME: make text bold on a button (seemingly impossible task for gtk)
            
        if iconfile:
            self.Pic = gtk.gdk.pixbuf_new_from_file_at_size(iconfile, Images.PG_iconsize, Images.PG_iconsize)
            self.Img = gtk.Image()
            self.Img.set_from_pixbuf(self.Pic)
            self.Button.set_alignment(0,0.5)
            self.Button.set_image(self.Img)
        self.Button.set_size_request(Images.PG_buttonwidth, Images.PG_iconsize+6)
        self.Button.set_relief(gtk.RELIEF_NONE)
        self.PLVBox.pack_start(self.Button, True,True, 0)
        self.Button.connect("button-press-event", self.PGListButtonClick)
        self.Button.show()
        return self.Button
        
    def PGListButtonClick(self,widget,event):
        # Lookup button's widget in ebuttonlist
        self.i = self.ebuttonlist.index(widget)
        self.etype = self.etypelist[self.i]
        if self.etype == 1:     #Sub list
            #Destroy old list items
            for item in self.ebuttonlist:
                item.destroy()
            #Add new menu items
            self.PrevMenus.append(self.CurMenu)
            self.ex = self.elist[self.i]
            self.XGDMenu(self.ex,1)
        elif self.etype == 0:                   #Menu Item
            self.ex = self.elist[self.i]
            self.exp = self.ex.getExec()
            print "launching item from application list..."
            print "command = " + self.exp
            os.defpath = Images.HomeDirectory       #FIXME: This did not set default path to home dir in testing
            self.expl = self.exp.split()
            if "%U" in self.expl:
                #Remove new file identifiers, as I don't know what to do with them
                self.expl.remove("%U")
            if "%F" in self.expl:
                self.expl.remove("%F")
            if self.expl[0].rfind(".sh",len(self.expl[0])-3,len(self.expl[0])) == -1:
                os.spawnvp(os.P_NOWAIT,self.expl[0],self.expl)
            else:
                print "Detected sh file, using gnome-open to launch"
                os.spawnvp(os.P_NOWAIT,"gnome-open",["gnome-open",self.expl[0]])
            self.internal_destroy(None,None)
        elif self.etype == 2:                                   #Menu Back button
            #Destroy old list items
            for item in self.ebuttonlist:
                item.destroy()
            self.CurMenu = self.PrevMenus.pop()
            #Add new menu items
            if self.CurMenu == self.BaseMenu:
                self.XGDMenu(self.CurMenu,0)
            else:
                self.XGDMenu(self.CurMenu,1)
        elif self.etype == 3:                                   #Recent Items button (file)
            self.i = self.ebuttonlist.index(widget)
            self.openpath = self.execlist[self.i]
            os.spawnvp(os.P_NOWAIT,"gnome-open",["gnome-open",self.openpath])
        elif self.etype == 4:                                                   #Recent Items button (directory)
            self.i = self.ebuttonlist.index(widget)
            self.openpath = self.execlist[self.i]
            os.spawnvp(os.P_NOWAIT,"nautilus",["nautilus",self.openpath])
        elif self.etype == 5:                                                       #Launch straight file from execlist (NoWait)
            self.i = self.ebuttonlist.index(widget)
            self.openpath = self.execlist[self.i]
            os.spawnvp(os.P_NOWAIT,self.openpath,[self.openpath])
        elif self.etype == 6:                                                   #ConstructMainMenu
            self.i = self.ebuttonlist.index(widget)
            self.openpath = self.execlist[self.i]
            os.spawnvp(os.P_WAIT,self.openpath,[self.openpath])
            ConstructMainMenu()
        elif self.etype == 7:                                                   #Properties changed
            self.i = self.ebuttonlist.index(widget)
            self.openpath = self.execlist[self.i]
            os.spawnvp(os.P_WAIT,self.openpath,[self.openpath])
            Images.ReloadSettings()
        
#=================================================================
#XGD MENU SYSTEM PARSER (Thanks to Piotr Zielinski for his examples)
#=================================================================
    def XGDMenu(self,menu, isbase):
        if isbase==0:       #Quickload the base menu
            self.elist = Images.elist
            self.ebuttonlist =  []
            
            self.etypelist = Images.etypelist
            
            for i in range(0,len(self.elist)-1):
                if self.etypelist[i] == 1:
                    self.ebuttonlist.append(self.AddButton(Images.ebuttonnamelist[i], Images.ebuttoniconlist[i],1))
                else:
                    self.ebuttonlist.append(self.AddButton(Images.ebuttonnamelist[i], Images.ebuttoniconlist[i],0))

        elif isbase == 1:    #Load tree menus
            self.elist = []
            self.ebuttonlist = []
            self.etypelist = []
            
            self.CurMenu = menu
            for entry in menu.getEntries():
                if isinstance(entry, xdg.Menu.Menu):
                    self.ebuttonlist.append(self.AddButton(entry.getName(), entry.getIcon(),1))
                    self.elist.append(entry)
                    self.etypelist.append(1)
                elif isinstance(entry, xdg.Menu.MenuEntry):
                    desktop = DesktopEntry(entry.DesktopEntry.getFileName())
                    self.dn = str(desktop.getName())
                    self.ebuttonlist.append(self.AddButton(desktop.getName(), desktop.getIcon(),0))
                    self.elist.append(desktop)
                    self.etypelist.append(0)
            self.ebuttonlist.append(self.AddButton("Back", "stock_left",1))
            self.elist.append(entry)
            self.etypelist.append(2)

    def geticonfile(self,icon):
        #Returns system icon paths
        iconpath = xdg.IconTheme.getIconPath(icon, Images.PG_iconsize, self.DefaultIconTheme, ["png", "xpm", "svg"])
        if not iconpath:
            iconpath = "/usr/share/icons/application-default-icon.png"
        return iconpath

#=================================================================
#RECENT ITEMS MENU
#=================================================================
    def CreateRIMenu(self):
        self.PrevMenus.append(self.CurMenu)
        #Destroy old list items
        for item in self.ebuttonlist:
            item.destroy()
        #Load xml doc (sloooooooooww)
        self.RIMenu = xml.dom.minidom.parse(Images.HomeDirectory + "/.recently-used.xbel")
        #Get an arbitrary value for the number of entries to this list
        self.RIlength = self.RIMenu.getElementsByTagName("bookmark").length * 2 - 1
        #Get the base node
        self.RIt = self.RIMenu.childNodes[0]
        #Clear our buffers
        self.ebuttonlist = []
        self.etypelist = []
        self.execlist = []
        #Add new items to list
        print Images.RI_numberofitems
        for i in range(0,Images.RI_numberofitems - 1):
            #milk the right URI from it
            self.RItv = self.RIt.childNodes[self.RIlength - i * 2].attributes["href"]
            self.RInames = self.RItv.value
            #Un-URI the path to make it readable by the os.path module
            self.RInames = urllib.url2pathname(self.RInames)
            self.RInames = self.RInames.replace("file://","")
            self.RInames = self.RInames.replace("%U","")
            self.RInames = self.RInames.replace("%F","")
            self.RInamess2 = self.RInames.split("/")
            self.RInamess = self.RInamess2.pop()
            if self.RInamess == "":
                self.RInamess = self.RInamess2.pop()
            if os.path.isfile(self.RInames):
                self.ebuttonlist.append(self.AddButton(self.RInamess, "fileopen",0))
                self.etypelist.append(3)
                self.execlist.append(self.RInames)
            elif os.path.isdir(self.RInames):
                self.ebuttonlist.append(self.AddButton(self.RInamess, "folder",0))
                self.etypelist.append(4)
                self.execlist.append(self.RInames)
            else:
                print "No file or directory exists for recent items object: " + self.RInames
            #Fixme: Detection for when there are less than Images.RI_numberofitems number of items in the recent items list
            #       This will just crash-land the function into oblivion at the moment.
            #Fixme: if file doesn't exist, add an extra one to list to make up 10 in total
        #Add a back button
        self.ebuttonlist.append(self.AddButton("Back", "stock_left",1))
        self.etypelist.append(2)
        #Clean up, to avoid major memory leak
        #FIXME: Memory leak!!!!!!!!
        self.RIMenu = ""
        self.RIt = ""
#=================================================================
#ADDITIONAL FUNCTIONS MENU
#=================================================================            

    def CreateAFMenu(self):
        self.PrevMenus.append(self.CurMenu)
        #Destroy old list items
        for item in self.ebuttonlist:
            item.destroy()

        self.elist = []
        self.ebuttonlist = []
        self.etypelist = []
        self.execlist = []
        
        self.ebuttonlist.append(self.AddButton("""About Me
Change user profile settings""", "user-info",0))
        self.etypelist.append(5)
        self.execlist.append("gnome-about-me")

        self.ebuttonlist.append(self.AddButton("""Appearance
Change appearance settings""", "gnome-settings-theme",0))
        self.etypelist.append(5)
        self.execlist.append("gnome-appearance-properties")
        
        self.ebuttonlist.append(self.AddButton("""Menu editor
Modify your start menu""", "alacarte",0))
        self.etypelist.append(6)
        self.execlist.append("alacarte")

        self.ebuttonlist.append(self.AddButton("""Screensaver
A legacy of phosphor""", "preferences-desktop-screensaver",0))
        self.etypelist.append(5)
        self.execlist.append("gnome-screensaver-preferences")
        
        self.ebuttonlist.append(self.AddButton("""System Monitor
Processes and performance""", "utilities-system-monitor",0))
        self.etypelist.append(5)
        self.execlist.append("gnome-system-monitor")

        self.ebuttonlist.append(self.AddButton("""Vista Menu
Manage this menu utility""", Images.IconDirectory + "start-here.png",0))
        self.etypelist.append(7)
        self.execlist.append(Images.ProgramDirectory+"Vista-Menu-Settings.py")
        #Add a back button
        self.ebuttonlist.append(self.AddButton("Back", "stock_left",1))
        self.etypelist.append(2)


#=================================================================
#SEARCH BAR
#=================================================================
    def SearchBarActivate(self,widget):
        self.searchitem = widget.get_text()
        os.spawnvp(os.P_NOWAIT,"tracker-search-tool",["tracker-search-tool",self.searchitem])
        
if __name__ == "__main__":
    ConstructMainMenu()
    hwg = Main_Menu()
    hwg.setup(0,0)
    gtk.main()
